@@ -37,6 +37,8 @@ class ReadableEnum(object):
 class SectorType(enum.Enum):
     industry = 1
     topic = 2
+    strategy = 3
+    scale = 4
 
 
 # 指数价格数据来源类型
