@@ -61,6 +61,20 @@ class DerivedDataApi(object):
             except Exception as e:
                 print(f'Failed to get data <err_msg> {e} from {FundIndicatorMonthly.__tablename__}')
 
+    def get_fund_indicator_group(self, start_date: str, end_date: str):
+        with DerivedDatabaseConnector().managed_session() as quant_session:
+            try:
+                query = quant_session.query(
+                    FundIndicatorGroup
+                )
+                query = query.filter(
+                    FundIndicatorGroup.datetime >= start_date,
+                    FundIndicatorGroup.datetime <= end_date
+                )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get data <err_msg> {e} from {FundIndicatorGroup.__tablename__}')
+
     def get_fund_score(self):
         with DerivedDatabaseConnector().managed_session() as quant_session:
             try:
@@ -119,30 +133,30 @@ class DerivedDataApi(object):
         with DerivedDatabaseConnector().managed_session() as mn_session:
             try:
                 query = mn_session.query(
-                    IndexValuation
+                    IndexValuationLongTerm
                 ).filter(
-                    IndexValuation.index_id.in_(index_ids),
-                    IndexValuation.datetime >= start_date,
-                    IndexValuation.datetime <= end_date,
-                ).order_by(IndexValuation.datetime.asc())
+                    IndexValuationLongTerm.index_id.in_(index_ids),
+                    IndexValuationLongTerm.datetime >= start_date,
+                    IndexValuationLongTerm.datetime <= end_date,
+                ).order_by(IndexValuationLongTerm.datetime.asc())
                 df = pd.read_sql(query.statement, query.session.bind)
                 return df
             except Exception as e:
-                print(f'Failed to get data <err_msg> {e} from {IndexValuation.__tablename__}')
+                print(f'Failed to get data <err_msg> {e} from {IndexValuationLongTerm.__tablename__}')
                 return pd.DataFrame([])
 
     def get_index_valuation_develop_without_date(self, index_ids):
         with DerivedDatabaseConnector().managed_session() as mn_session:
             try:
                 query = mn_session.query(
-                    IndexValuation
+                    IndexValuationLongTerm
                 ).filter(
-                    IndexValuation.index_id.in_(index_ids),
-                ).order_by(IndexValuation.datetime.asc())
+                    IndexValuationLongTerm.index_id.in_(index_ids),
+                ).order_by(IndexValuationLongTerm.datetime.asc())
                 df = pd.read_sql(query.statement, query.session.bind)
                 return df
             except Exception as e:
-                print(f'Failed to get data <err_msg> {e} from {IndexValuation.__tablename__}')
+                print(f'Failed to get data <err_msg> {e} from {IndexValuationLongTerm.__tablename__}')
                 return pd.DataFrame([])
 
     def get_asset_allocation_info(self, version:int=2):
@@ -176,6 +190,20 @@ class DerivedDataApi(object):
                 print(f'Failed to get_style_factor_return {e} from {StyleAnalysisFactorReturn.__tablename__}')
                 return
 
+    def get_barra_cne5_factor_return(self, start_date: str, end_date: str):
+        with DerivedDatabaseConnector().managed_session() as session:
+            try:
+                query = session.query(
+                    BarraCNE5FactorReturn
+                ).filter(
+                    BarraCNE5FactorReturn.datetime >= start_date,
+                    BarraCNE5FactorReturn.datetime <= end_date,
+                )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get_style_factor_return {e} from {StyleAnalysisFactorReturn.__tablename__}')
+                return
+
     def get_allocation_distribution(self, version:str=1):
         with DerivedDatabaseConnector().managed_session() as session:
             try:
