@@ -898,7 +898,7 @@ class RawDataApi:
             except Exception as e:
                 print('Failed to get data <err_msg> {}'.format(e))
 
-    def em_stock_dividend(self, end_date: str = ''):
+    def get_em_stock_dividend(self, end_date: str = ''):
         with RawDatabaseConnector().managed_session() as raw_session:
             try:
                 query = raw_session.query(EmStockDividend)
@@ -910,7 +910,7 @@ class RawDataApi:
             except Exception as e:
                 print(f'Failed to get data <err_msg> {e} from {EmStockDividend.__tablename__}')
 
-    def em_bond_rating(self, end_date: str = ''):
+    def get_em_bond_rating(self, end_date: str = ''):
         with RawDatabaseConnector().managed_session() as raw_session:
             try:
                 query = raw_session.query(EmBondRating)
