@@ -1,4 +1,5 @@
 
+import time
 from typing import Union
 
 import pandas as pd
@@ -20,10 +21,14 @@ def score_rescale(a: pd.DataFrame) -> np.ndarray:
 class DerivedDataHelper:
     def __init__(self):
         self._updated_count = defaultdict(int)
+        self._timer = time.monotonic()
 
     def _upload_derived(self, df, table_name):
         print(table_name)
         # print(df)
         df.to_sql(table_name, DerivedDatabaseConnector().get_engine(), index=False, if_exists='append')
 
+        now: float = time.monotonic()
+        print(f'{table_name} costs {now - self._timer}s')
+        self._timer = now
         self._updated_count[table_name] += df.shape[0]
