@@ -7,6 +7,7 @@ from ...wrapper.mysql import BasicDatabaseConnector, DerivedDatabaseConnector
 from ...api.basic import *
 from ...view.derived_models import *
 
+
 class IndexIndicatorProcessor(object):
     w1 = 5
     m1 = 20
@@ -19,9 +20,9 @@ class IndexIndicatorProcessor(object):
 
     def __init__(self, data_helper):
         self._data_helper = data_helper
-        
+
     def history_init(self):
-        with BasicDatabaseConnector().managed_session() as db_session:    
+        with BasicDatabaseConnector().managed_session() as db_session:
             query = db_session.query(IndexPrice).filter(IndexPrice.datetime >= datetime.date(2010,1,1))
             self.index_price = pd.read_sql(query.statement, query.session.bind)
             self.index_price = self.index_price.pivot_table(index='datetime', columns='index_id', values='close').fillna(method='ffill').fillna(method='bfill')
@@ -29,7 +30,7 @@ class IndexIndicatorProcessor(object):
 
     def init(self, end_date:str='20200715'):
         self.end_date = datetime.datetime.strptime(end_date,'%Y%m%d').date()
-        with BasicDatabaseConnector().managed_session() as db_session:    
+        with BasicDatabaseConnector().managed_session() as db_session:
             query = db_session.query(IndexPrice).filter(IndexPrice.datetime <= self.end_date,
                                                         IndexPrice.datetime >= datetime.date(2005,1,1))
             self.index_price = pd.read_sql(query.statement, query.session.bind)
@@ -38,7 +39,7 @@ class IndexIndicatorProcessor(object):
             query = db_session.query(TradingDayList)
             trade_day_df = pd.read_sql(query.statement, query.session.bind).drop(columns='_update_time')
             begin_d = self.index_price_vol_part.index[0]
-            end_d = self.index_price_vol_part.index[-1]  
+            end_d = self.index_price_vol_part.index[-1]
             trade_day_list = trade_day_df.datetime
             trade_day_index = trade_day_list[(trade_day_list>=begin_d) & (trade_day_list<=end_d)]
             self.index_price_vol_part = self.index_price_vol_part.reindex(trade_day_index).pct_change(1)
@@ -183,11 +184,11 @@ class IndexIndicatorProcessor(object):
         result_vol = self._process_update_result(self.vol_res)
         result_vol = result_vol.replace(np.Inf,None).replace(-np.Inf,None).drop_duplicates(subset=['index_id','datetime'])
         return result_vol
-        
+
     def process(self, end_date):
         failed_tasks = []
         try:
-            #一次load 
+            #一次load
             self.init(end_date=end_date)
             result_ret = self._update_ret()
             self._data_helper._upload_derived(result_ret, IndexReturn.__table__.name)
@@ -196,7 +197,7 @@ class IndexIndicatorProcessor(object):
             print(e)
             traceback.print_exc()
             failed_tasks.append('index_return')
-        
+
         try:
             result_vol = self._update_vol()
             self._data_helper._upload_derived(result_vol, IndexVolatility.__table__.name)
@@ -204,4 +205,17 @@ class IndexIndicatorProcessor(object):
             print(e)
             traceback.print_exc()
             failed_tasks.append('index_volatility')
-        return failed_tasks
\ No newline at end of file
+        return failed_tasks
+
+
+if __name__ == '__main__':
+    from .derived_data_helper import DerivedDataHelper
+    from ...api.basic import BasicDataApi
+
+    trading_days = BasicDataApi().get_trading_day_list('20200713', '20200821')
+    iip = IndexIndicatorProcessor(DerivedDataHelper())
+    for date in trading_days.datetime:
+        date = date.strftime('%Y%m%d')
+        print(f'deal with {date}')
+        if iip.process(date):
+            break
