@@ -10,6 +10,7 @@ import statsmodels.api as sm
 from scipy.optimize import Bounds, minimize
 from statsmodels.tsa.ar_model import AutoReg
 from ...api.basic import BasicDataApi
+from ...view.derived_models import FundIndicatorGroup
 
 
 class FundIndicatorProcessorGroup:
@@ -51,7 +52,7 @@ class FundIndicatorProcessorGroup:
 
         index_price: pd.DataFrame = self._basic_api.get_index_price_dt(start_date, end_date).drop(columns='_update_time')
         # 有的index最近没有数据，如活期存款利率/各种定期存款利率等，需要先reindex到全部的交易日列表上ffill
-        self._index_price: pd.DataFrame = index_price.pivot_table(index='datetime', columns='index_id', values='close').reindex(self._trading_days.index)  #.fillna(method='ffill')
+        self._index_price: pd.DataFrame = index_price.pivot_table(index='datetime', columns='index_id', values='close').reindex(self._trading_days.index).fillna(method='ffill')
         _bank_rate_df: pd.DataFrame = self._basic_api.get_index_price(index_list=['ddir', 'nonor', 'tmd_1y', 'tmd_2y', 'tmd_3m', 'tmd_3y', 'tmd_5y', 'tmd_6m', 'tmd_7d']).drop(columns='_update_time')
         _bank_rate_df = _bank_rate_df.pivot_table(index='datetime', columns='index_id', values='close').reindex(all_trading_days.index).fillna(method='ffill').reindex(self._trading_days.index)
         self._index_price: pd.DataFrame = pd.concat([self._index_price, _bank_rate_df], axis=1)
@@ -408,6 +409,7 @@ class FundIndicatorProcessorGroup:
         failed_tasks: List[str] = []
         try:
             self.init(start_date, end_date)
+            print('init done, to calc indicators')
             self.calculate()
             self._data_helper._upload_derived(self._result, FundIndicatorGroup.__table__.name)
         except Exception as e:
