@@ -223,7 +223,7 @@ class FundIndicatorProcessor(object):
         df['sharpe'] = (df.annual_ret - self.RISK_FEE_RATE) / df.annual_vol
         df = df.drop(['fund','benchmark','vol_benchmark','mean_ret_no_free_ret','mean_ret_benchmark','mean_ret'], axis=1)
         # build history insert
-        df = df.replace(np.Inf,None).replace(-np.Inf,None).dropna(subset=['beta', 'alpha','track_err']).reset_index()
+        df = df.replace({-np.Inf:None,np.Inf:None}).dropna(subset=['beta', 'alpha','track_err']).reset_index()
         #self._data_helper._upload_derived(df, FundIndicatorDev.__table__.name)
         return df
 
@@ -265,7 +265,7 @@ class FundIndicatorProcessor(object):
             print(f'index {index_id} finish')
         result = [ _ for _ in result if not _ is None]
         self.result = pd.DataFrame(result)
-        self.result = self.result.replace(np.Inf,None).replace(-np.Inf,None).dropna(subset=['beta', 'alpha','track_err'])
+        self.result = self.result.replace({-np.Inf:None,np.Inf:None}).dropna(subset=['beta', 'alpha','track_err'])
 
     def process(self, start_date, end_date):
         failed_tasks = []
