@@ -249,13 +249,40 @@ class RqRawDataDownloader(object):
             traceback.print_exc()
             return False
 
-    def stock_minute(self):
+    def stock_minute(self, to_save):
         try:
             stock_order_book_id_list = rq.all_instruments(type='CS', market='cn')['order_book_id'].tolist()
             df = rq.current_minute(stock_order_book_id_list, skip_suspended=True)
             if df is not None:
+                today_date = datetime.date.today()
+                today = datetime.datetime(today_date.year, today_date.month, today_date.day)
                 df.reset_index(inplace=True)
-                self._data_helper._upload_raw(df, RqStockMinute.__table__.name)
+                df = df[df['datetime'] >= today]
+                if to_save:
+                    try:
+                        self._data_helper._upload_raw(df, RqStockMinute.__table__.name)
+                    except Exception as e:
+                        print(e)
+                        traceback.print_exc()
+            return df
+        except Exception as e:
+            print(e)
+            traceback.print_exc()
+            return None
+
+    def index_minute(self):
+        # Get index list
+        try:
+            index_df = BasicDataApi().get_index_info()
+            index_list = [order_book_id for order_book_id in index_df['order_book_id'].tolist()
+                if order_book_id and order_book_id != 'not_available' and '.' in order_book_id]
+            df = rq.current_minute(index_list, skip_suspended=True)
+            if df is not None:
+                today = datetime.date.today()
+                df.reset_index(inplace=True)
+                df = df[df['datetime'] >= today]
+                # self._data_helper._upload_raw(df, RqIndexMinute.__table__.name)
+            print(df)
             return df
         except Exception as e:
             print(e)
