@@ -5,7 +5,7 @@ from sqlalchemy import func
 from ...wrapper.mysql import (RawDatabaseConnector, BasicDatabaseConnector, DerivedDatabaseConnector, 
     ViewDatabaseConnector)
 from ...view.view_models import FundDailyCollection
-from ...view.basic_models import FundNav, FundInfo, FundRate, FundSize, FundRet, FundBenchmark, IndexInfo
+from ...view.basic_models import FundNav, FundInfo, FundRate, FundSize, FundRet, FundBenchmark, IndexInfo, FundStatusLatest
 from ...view.derived_models import FundAlpha, FundScore, FundIndicator
 from ....constant import ExchangeStatus
 
@@ -19,7 +19,8 @@ class FundDailyCollectionProcessor(object):
                     FundInfo.wind_class_1,
                     FundInfo.wind_class_2,
                     FundInfo.start_date,
-                    FundInfo.manager_id,
+                    # FundInfo.manager_id,
+                    FundInfo.fund_manager,
                     FundInfo.company_id,
                     FundInfo.benchmark,
                     FundInfo.desc_name,
@@ -188,6 +189,22 @@ class FundDailyCollectionProcessor(object):
             except Exception as e:
                 print('Failed fill get data <err_msg> {}'.format(e))
 
+    def get_exchange_status_df(self):
+        with BasicDatabaseConnector().managed_session() as mn_session:
+            try:
+                query = mn_session.query(
+                    FundStatusLatest.fund_id,
+                    FundStatusLatest.PURCHSTATUS,
+                    FundStatusLatest.REDEMSTATUS,
+                    FundStatusLatest.LPLIMIT,
+                    FundStatusLatest.OTCLPLIMIT,
+                )
+                df = pd.read_sql(query.statement, query.session.bind)
+                print(df)
+                return df
+            except Exception as e:
+                print('Failed fill get data <err_msg> {}'.format(e))
+
     def get_alpha_df(self):
         with DerivedDatabaseConnector().managed_session() as mn_session:
             try:
@@ -356,6 +373,10 @@ class FundDailyCollectionProcessor(object):
             print(tag_indicator)
             print('-' * 100)
 
+            exchange_status = self.get_exchange_status_df().set_index('fund_id')
+            print(exchange_status)
+            print('-' * 100)
+
             print('处理机构评级')
             rating = self.get_institution_rating_df()
             rating = rating.drop_duplicates(subset=['fund_id'], keep='last')
@@ -364,7 +385,7 @@ class FundDailyCollectionProcessor(object):
             print('-' * 100)
 
             print('处理净值')
-            df = pd.concat([funds, bench, nav, alpha, size, rating, score, tag_indicator], axis=1, sort=False)
+            df = pd.concat([funds, bench, nav, alpha, size, rating, score, tag_indicator, exchange_status], axis=1, sort=False)
             df.index.name = 'fund_id'
             print('_'*100)
             print(df)
@@ -382,12 +403,10 @@ class FundDailyCollectionProcessor(object):
             df = df.dropna(subset=['fund_id'])
             df['exchange_status'] = df.apply(self.get_exchange_status, axis=1)
             df['found_to_now'] = df['start_date'].apply(self.get_found_to_now)
-            df['manager_id'] = df['manager_id'].apply(self.modify_fund_manager)
             df = df.rename(columns={
                 'wind_class_1': 'wind_class_I',
                 'wind_class_2': 'wind_class_II',
                 'start_date': 'found_date',
-                'manager_id': 'fund_manager',
                 'company_id': 'company_name',
                 'desc_name': 'symbol',
             })
