@@ -6,6 +6,7 @@ import numpy as np
 import datetime
 import time
 import io
+import copy
 import contextlib
 from ..wrapper.mysql import RawDatabaseConnector, BasicDatabaseConnector, DerivedDatabaseConnector
 from .fund_info_filter import filter_fund_info, fund_info_update
@@ -49,6 +50,7 @@ class FundDataManager(DataManager):
         self._is_inited = False
         self._score_manager = score_manager or FundScoreManager()
         self.set_score_param(self._fund_score_param)
+        self.fund_list_with_nav = set()
 
     @property
     def inited(self):
@@ -78,6 +80,7 @@ class FundDataManager(DataManager):
             _filter_fund_info = filter_fund_info(self.dts.fund_info, index_list, is_normal_type, is_mix_type)
             _tm_basic_filter_info = time.time()
             self.dts.fund_list = set(_filter_fund_info.fund_id)
+            self.fund_list_with_nav = copy.deepcopy(self.dts.fund_list)
             self.dts.fund_index_map = {cur.fund_id: cur.index_id for cur in _filter_fund_info.itertuples()}
             self.end_date_dic = self.dts.fund_info[['fund_id', 'end_date']].set_index('fund_id').to_dict()['end_date']
             _tm_basic_prep_struct = time.time()
@@ -200,12 +203,12 @@ class FundDataManager(DataManager):
             _tm_deriv_fetch_index_pct = time.time()
             pct_index_list = list(TaaTunerParam.POOL.keys())
             _index_pct_query = derived_session.query(
-                    IndexValuation
+                    IndexValuationLongTerm
                 ).filter(
-                    IndexValuation.index_id.in_(pct_index_list),
-                    IndexValuation.datetime >= self.start_date,
-                    IndexValuation.datetime <= self.end_date,
-                ).order_by(IndexValuation.datetime.asc())
+                    IndexValuationLongTerm.index_id.in_(pct_index_list),
+                    IndexValuationLongTerm.datetime >= self.start_date,
+                    IndexValuationLongTerm.datetime <= self.end_date,
+                ).order_by(IndexValuationLongTerm.datetime.asc())
             self._index_pct_df = pd.read_sql(_index_pct_query.statement, _index_pct_query.session.bind).set_index('index_id')
             # 按照trading date 作为index, fillna
             date_list = self.dts.trading_days.datetime.tolist()
@@ -215,7 +218,8 @@ class FundDataManager(DataManager):
                 df.loc[:, 'index_id'] = index_id
                 res.append(df)
             _index_pct_df = pd.concat(res, axis=0)
-            self.dts.index_pct = _index_pct_df.pivot_table(index=['datetime', 'index_id'], values=['pe_pct', 'pb_pct', 'ps_pct'])
+            self.dts.index_pct = _index_pct_df[['datetime','index_id','pe_pct_5_3','pb_pct_5_3','ps_pct_5_3']].rename(
+                columns={'pe_pct_5_3':'pe_pct','pb_pct_5_3':'pb_pct','ps_pct_5_3':'ps_pct'}).pivot_table(index=['datetime', 'index_id'], values=['pe_pct', 'pb_pct', 'ps_pct'])
             self.dts.index_date_list = self.dts.index_pct.index.remove_unused_levels().levels[0]
             _tm_deriv_apply_index_pct = time.time()
 
@@ -351,6 +355,52 @@ class FundDataManager(DataManager):
         df = self.dts.fund_unit_nav
         return df.loc[dt].to_dict()
 
+    def confirm_fund_nav_exists(self, fund_ids):
+        # param "fund_id" is str (id) or list of str (id_list)
+        # get fund nav from db
+        fund_list = []
+        if type(fund_ids) is list:
+            fund_list = fund_ids
+        elif type(fund_ids) is str:
+            fund_list = [fund_ids]
+        fund_list_without_nav = []
+        for fund_id in fund_list:
+            if fund_id not in self.fund_list_with_nav:
+                self.fund_list_with_nav.add(fund_id)
+                fund_list_without_nav.append(fund_id)
+        # print(f'fund_list: {fund_list}')
+        # print(f'fund_list_without_nav: {fund_list_without_nav}')
+        if fund_list_without_nav:
+            with BasicDatabaseConnector().managed_session() as quant_session:
+                _fund_nav_query = quant_session.query(
+                    FundNav.fund_id,
+                    FundNav.adjusted_net_value,
+                    FundNav.unit_net_value,
+                    FundNav.datetime
+                ).filter(
+                    FundNav.fund_id.in_(fund_list_without_nav),
+                    FundNav.datetime >= self.start_date,
+                    FundNav.datetime <= self.end_date,
+                )
+                _nav_df = pd.read_sql(_fund_nav_query.statement, _fund_nav_query.session.bind)
+
+                # 这里我们制作一个总的pivot_table再取值，会比分别两次pivot_table快一些
+                # 如果index-column pair有重复的值，pivot会报错而pivot_table不会，所以这里用pivot也许更好些
+                # 但是pivot里边会调用set_index，导致datetime列的dtype从object变为datetime64[ns]
+                _temp_fund_nav = _nav_df.pivot_table(index='datetime', columns='fund_id')
+
+                self.dts.fund_nav = self.dts.fund_nav.join(
+                    _temp_fund_nav['adjusted_net_value'].dropna(axis=1, how='all').fillna(method='ffill'), 
+                    how='outer'
+                )
+                self.dts.fund_unit_nav = self.dts.fund_unit_nav.join(
+                    _temp_fund_nav['unit_net_value'].dropna(axis=1, how='all').fillna(method='ffill'), 
+                    how='outer'
+                )
+
+        print(f'[fund_list_without_nav] fund_ids added : {fund_list_without_nav}')
+        return fund_list_without_nav
+
     def get_fund_purchase_fees(self):
         return self.dts.fund_info.set_index('fund_id').purchase_fee.to_dict()
 
