@@ -192,7 +192,7 @@ class FundPosItem:
             else: #非清仓卖出 平均成本不变
                 pass
         self.update_time = trade.trade_date
-        self.unit_volume += trade.fund_unit_volume
+        self.unit_volume += trade.fund_unit_volume if trade.fund_unit_volume else 0
         assert self.volume >= -1e-8, f'fund backtest vol {self.volume} has negative value: '
         assert self.avg_cost >= -1e-8, f"fund avg cost can not be negative! (fund_id){self.fund_id} (update time){self.update_time}"
         return True
@@ -295,11 +295,11 @@ class AssetTradeCache:
 @dataclasses.dataclass
 class FundWeightItem:
 
-    fund_id: str                # 基金ID
-    index_id: str               # 基金所属的大类资产
-    asset_wgt: float            # 资产的wgt
-    fund_wgt_in_asset: float    # 基金在所属资产中的wgt
-    fund_wgt: float=None        # 基金在整体组合中的wgt
+    fund_id: str                    # 基金ID
+    index_id: str=None              # 基金所属的大类资产
+    asset_wgt: float=None           # 资产的wgt
+    fund_wgt_in_asset: float=None   # 基金在所属资产中的wgt
+    fund_wgt: float=None            # 基金在整体组合中的wgt
 
     def __post_init__(self):
         self.fund_wgt = self.fund_wgt or self.asset_wgt * self.fund_wgt_in_asset
