@@ -29,6 +29,10 @@ class FundDailyCollection(Base):
     exchange_status = Column(CHAR(20))  # 交易状态
     theme = Column(CHAR(20))  # 基金主题
     track_index = Column(CHAR(20)) # 跟踪指数
+    purch_status = Column(CHAR(16))  # 申购状态
+    redem_status = Column(CHAR(16))  # 赎回状态
+    lp_limit = Column(DOUBLE(asdecimal=False))  # 暂停大额申购上限
+    otc_lp_limit = Column(DOUBLE(asdecimal=False))  # 场外暂停大额申购上限
 
     unit_net_value = Column(DOUBLE(asdecimal=False))  # 单位净值
     acc_net_value = Column(DOUBLE(asdecimal=False))  # 累计单位净值
@@ -125,6 +129,11 @@ class FundDailyCollection(Base):
             'track_index': '跟踪指数',
 
             'exchange_status': '交易状态',
+            'purch_status': '申购状态',
+            'redem_status': '赎回状态',
+            'lp_limit': '暂停大额申购上限',
+            'otc_lp_limit': '场外暂停大额申购上限',
+
             'theme': '基金主题',
             'adjusted_net_value': '复权净值',
             'unit_net_value': '净值',
@@ -256,6 +265,7 @@ class IndexDailyCollection(Base):
     open = Column(DOUBLE(asdecimal=False))  # 开盘价
     total_turnover = Column(DOUBLE(asdecimal=False))  # 成交额
     ret = Column(DOUBLE(asdecimal=False))  # 收益率
+    yest_close = Column(DOUBLE(asdecimal=False))  # 前收盘价
 
     order_book_id = Column(CHAR(20))  # 米筐ID
     industry_tag = Column(CHAR(64))  # 行业标签
@@ -311,6 +321,7 @@ class IndexDailyCollection(Base):
             'open': '开盘价',
             'total_turnover': '成交额',
             'ret': '收益率',
+            'yest_close': '前收盘价',
 
             'order_book_id': '指数代码',
             'industry_tag': '行业标签',
