@@ -9,8 +9,10 @@ import os
 import time
 
 from .asset_helper import SAAHelper, TAAHelper, FAHelper
-from .trader import AssetTrader, FundTrader
+from .trader import AssetTrader, FundTrader, BasicFundTrader
 from .report import ReportHelper
+from ...data.constant import _DEFAULT_CASH_VALUE
+from ...data.struct import FundTrade, FundWeight, FundWeightItem
 from ...data.manager.manager_fund import FundDataManager
 from ...data.manager.score import ScoreFunc, FundScoreManager
 from ...data.struct import AssetWeight, AssetPrice, AssetPosition, AssetValue
@@ -19,7 +21,7 @@ from ...util.calculator import Calculator
 
 class FundEngine:
 
-    DEFAULT_CASH_VALUE = 1e8
+    DEFAULT_CASH_VALUE = _DEFAULT_CASH_VALUE
 
     def __init__(self, data_manager: FundDataManager, trader, taa_params:TAAParam=None, fa_params:FAParam=None, taa_param_details:dict=None, is_old_version=False, white_list:set=None, black_list:set=None, fund_score_funcs: Optional[Dict[str, Union[ScoreFunc, str]]] = None):
         self._dm = data_manager
@@ -152,6 +154,9 @@ class FundEngine:
 class FundBacktestEngine(FundEngine):
 
     def run(self, saa: AssetWeight, start_date: datetime.date=None, end_date: datetime.date=None, cash: float=None, print_time=False):
+        # setup helpers
+        self.setup(saa)
+
         cash = cash or self.DEFAULT_CASH_VALUE
         # init position
         self.cur_asset_position = AssetPosition(cash=cash)
@@ -165,9 +170,6 @@ class FundBacktestEngine(FundEngine):
         start_date = start_date if isinstance(start_date, datetime.date) else datetime.datetime.strptime(start_date,'%Y%m%d').date()
         end_date = end_date if isinstance(end_date, datetime.date) else datetime.datetime.strptime(end_date,'%Y%m%d').date()
 
-        # setup helpers
-        self.setup(saa)
-
         # loop trading days
         _dts = self._dm.get_trading_days()
         dts = _dts[(_dts.datetime >= start_date) & (_dts.datetime <= end_date)].datetime # df with datetime.date
@@ -234,6 +236,165 @@ class FundBacktestEngine(FundEngine):
     def get_last_target_fund_allocation(self):
         return self._report_helper.get_last_target_fund_allocation(self._prep_target_fund_allocation.funds)
 
+class BasicFundBacktestEngine(object):
+
+    DEFAULT_CASH_VALUE = _DEFAULT_CASH_VALUE
+
+    def __init__(self, data_manager:FundDataManager, trader, fund_weight_list:list):
+        self._dm = data_manager
+        fund_ids = []
+        for dt, fund_weight in fund_weight_list:
+            for fund_id, weight in fund_weight:
+                fund_ids.append(fund_id)
+        self._dm.confirm_fund_nav_exists(fund_ids)
+        self._report_helper = ReportHelper()
+        self._pending_trades = []
+        self._trader = trader
+        self._target_fund_weight = {}
+        for dt, fund_weight in fund_weight_list:
+            dt = dt if isinstance(dt, datetime.date) else datetime.datetime.strptime(dt,'%Y-%m-%d').date()
+            self._target_fund_weight[dt] = fund_weight
+
+    def init(self):
+        if not self._dm.inited:
+            self._dm.init()
+        self._report_helper.init()
+        self._trader.init()
+        # preps
+        self._prep_fund_purchase_fees = None
+        self._prep_fund_redeem_fees = None
+        self._prep_asset_price = None
+        self._prep_fund_nav = None
+        self._prep_fund_unit_nav = None
+
+    def setup(self):
+        # setup helpers
+        self._report_helper.setup()
+        self._trader.setup()
+
+    def prep_data(self, dt):
+        # basic
+        if not self._prep_fund_purchase_fees:
+            self._prep_fund_purchase_fees = self._dm.get_fund_purchase_fees()
+        if not self._prep_fund_redeem_fees:
+            self._prep_fund_redeem_fees = self._dm.get_fund_redeem_fees()
+        # DATA
+        self._prep_asset_price = self._dm.get_index_price_data(dt)
+        self._prep_fund_nav = self._dm.get_fund_nav(dt)
+        self._prep_fund_unit_nav = self._dm.get_fund_unit_nav(dt)
+
+    def calc_trade(self, dt, cur_asset_position: AssetPosition, cur_fund_position: FundPosition=None, is_real_trade=False):
+        # TODO: if is_real_trade, use nv instead of nav
+        if dt not in self._target_fund_weight:
+            return []
+
+        curr_target_fund_weight = FundWeight()
+        for fund_id, weight in self._target_fund_weight[dt]:
+            # TODO: what if fund_id does not belong to any index! e.g. 000001!0
+            if fund_id in self._dm.dts.fund_index_map:
+                index_id = self._dm.dts.fund_index_map[fund_id]
+            else:
+                index_id = 'hs300' # TODO
+
+            curr_target_fund_weight.add(FundWeightItem(fund_id=fund_id, fund_wgt=weight, 
+                                                       index_id=index_id, asset_wgt=0, fund_wgt_in_asset=0))
+        self._report_helper.update_rebalance_detail(dt, 'Change fund weight')
+        v_fund_position, fund_trade_list = self._trader.calc_fund_trade(
+            dt, curr_target_fund_weight, cur_fund_position, self._prep_fund_nav, 
+            self._prep_fund_purchase_fees, self._prep_fund_redeem_fees)
+        return fund_trade_list
+
+    def finalize_trade(self, dt, trades: list, cur_asset_position: AssetPosition, cur_fund_position: FundPosition=None, disproved_set: set={}):
+        assert cur_fund_position, 'cur_fund_position should not be None in fund backtest run'
+        self._pending_trades, traded_list = self._trader.finalize_trade(dt, trades, 
+            self._prep_asset_price, cur_asset_position, cur_fund_position, self._prep_fund_nav, self._prep_fund_unit_nav,
+            self._prep_fund_purchase_fees, self._prep_fund_redeem_fees, disproved_set)
+        return traded_list 
+
+    def update_reporter(self, dt, trade_list, cur_asset_position: AssetPosition, cur_fund_position: FundPosition=None):
+        self._report_helper.update(dt, cur_asset_position, self._prep_asset_price, self._pending_trades, 
+            cur_fund_position, self._prep_fund_nav, trade_list, None, None, None)
+
+    def run(self, start_date:datetime.date=None, end_date:datetime.date=None, cash:float=None, print_time=False):
+        # setup helpers
+        self.setup()
+
+        cash = cash or self.DEFAULT_CASH_VALUE
+        # init position
+        self.cur_asset_position = AssetPosition(cash=cash) # TODO
+        self.cur_fund_position = FundPosition(cash=cash)
+        self._pending_trades = []
+
+        # init days
+        start_date = start_date or self._dm.start_date
+        end_date = end_date or self._dm.end_date
+        start_date = start_date if isinstance(start_date, datetime.date) else datetime.datetime.strptime(start_date,'%Y%m%d').date()
+        end_date = end_date if isinstance(end_date, datetime.date) else datetime.datetime.strptime(end_date,'%Y%m%d').date()
+
+        # loop trading days
+        _dts = self._dm.get_trading_days()
+        dts = _dts[(_dts.datetime >= start_date) & (_dts.datetime <= end_date)].datetime # df with datetime.date
+        for t in dts:
+            self._run_on(t, print_time=print_time)
+        # init report data
+        self._report_helper.plot_init(self._dm)
+
+    def _run_on(self, dt, print_time=False):
+        _tm_start = time.time()
+        # prep data
+        self.prep_data(dt)
+        _tm_prep_data = time.time()
+        # finalize trade
+        traded_list = self.finalize_trade(dt, self._pending_trades, self.cur_asset_position, self.cur_fund_position)
+        _tm_finalize_trade = time.time()
+        # calc trade
+        trade_list = self.calc_trade(dt, self.cur_asset_position, self.cur_fund_position)
+        _tm_calc_trade = time.time()
+        # book trade
+        self.book_trades(trade_list)
+        # update
+        self.update_reporter(dt, traded_list, self.cur_asset_position, self.cur_fund_position)
+        if self._pending_trades:
+            print(self._pending_trades)
+        _tm_finish = time.time()
+
+        if print_time:
+            print(f'{dt} (tot){_tm_finish - _tm_start} (finalize){_tm_finalize_trade - _tm_start} (calc){_tm_calc_trade - _tm_finalize_trade} (misc){_tm_finish - _tm_calc_trade}')
+
+    def book_trades(self, trade_list: list):
+        if trade_list and len(trade_list) > 0:
+            self._pending_trades += trade_list
+
+    def get_fund_result(self):
+        return self._report_helper.get_fund_stat()
+
+    def get_asset_trade(self):
+        return self._report_helper.get_asset_trade()
+
+    def get_fund_trade(self):
+        return self._report_helper.get_fund_trade()
+        
+    def plot(self, is_asset:bool=True, is_fund:bool=True):
+        if is_asset:
+            self._report_helper.backtest_asset_plot()
+        if is_fund:
+            self._report_helper.backtest_fund_plot()
+    
+    def plot_score(self, index_id, is_tuning=False):
+        #['csi500', 'gem', 'gold', 'hs300', 'national_debt', 'sp500rmb']
+        self._report_helper._plot_fund_score(index_id, is_tuning)
+
+    def plot_taa(self, saa_mv, taa_mv, index_id):
+        #['csi500', 'hs300', 'gem', 'sp500rmb']
+        self._report_helper._plot_taa_saa(saa_mv, taa_mv, index_id)
+        self._report_helper._index_pct_plot(index_id, saa_mv, taa_mv)
+
+    def get_last_position(self):
+        return self._report_helper.get_last_position()
+
+    def get_last_target_fund_allocation(self):
+        return self._report_helper.get_last_target_fund_allocation(self._prep_target_fund_allocation.funds)
+
 def saa_backtest(m: FundDataManager, saa: AssetWeight):
     asset_param = AssetTradeParam() # type in here
     t = AssetTrader(asset_param)
@@ -477,6 +638,169 @@ def test():
     # change_score_function(m, saa)
     # change_formula_score_function(m, saa)
 
+
+params_str = '''
+{
+    "back_test_type": "basic",
+    "fund_weight_list": [
+        [
+            "2020-01-06",
+            [
+                [
+                    "007404!0",
+                    0.1
+                ],
+                [
+                    "008779!0",
+                    0.3
+                ],
+                [
+                    "004603!0",
+                    0.6
+                ]
+            ]
+        ],
+        [
+            "2020-02-06",
+            [
+                [
+                    "004603!0",
+                    0.3
+                ],
+                [
+                    "000914!0",
+                    0.3
+                ],
+                [
+                    "005480!0",
+                    0.2
+                ],
+                [
+                    "007404!0",
+                    0.2
+                ]
+            ]
+        ],
+        [
+            "2020-06-01",
+            [
+                [
+                    "511880!0",
+                    0.1
+                ],
+                [
+                    "000356!0",
+                    0.9
+                ]
+            ]
+        ]
+    ],
+    "start_date": "2020-01-01",
+    "end_date": "2020-08-19"
+}
+'''
+
+untagged_params_str = '''
+{
+    "back_test_type": "basic",
+    "fund_weight_list": [
+        [
+            "2020-01-06",
+            [
+                [
+                    "000001!0",
+                    0.1
+                ],
+                [
+                    "000003!0",
+                    0.3
+                ],
+                [
+                    "004603!0",
+                    0.6
+                ]
+            ]
+        ],
+        [
+            "2020-02-06",
+            [
+                [
+                    "004603!0",
+                    0.3
+                ],
+                [
+                    "000914!0",
+                    0.3
+                ],
+                [
+                    "005480!0",
+                    0.2
+                ],
+                [
+                    "007404!0",
+                    0.2
+                ]
+            ]
+        ],
+        [
+            "2020-06-01",
+            [
+                [
+                    "511880!0",
+                    0.1
+                ],
+                [
+                    "000356!0",
+                    0.9
+                ]
+            ]
+        ]
+    ],
+    "start_date": "2020-01-01",
+    "end_date": "2020-08-19"
+}
+'''
+
+params_str_1 = '''
+{
+    "back_test_type": "basic",
+    "fund_weight_list": [
+        [
+            "2020-06-01",
+            [
+                [
+                    "000001!0",
+                    1
+                ]
+            ]
+        ]
+    ],
+    "start_date": "2020-06-01",
+    "end_date": "2020-08-19"
+}
+'''
+
+def test1():
+    import json
+    import pickle
+    with open('/shared/robo-advisor/temp/data_manager', 'rb') as fp:
+        data_manager = pickle.load(fp)
+
+    t = BasicFundTrader()
+
+    params = json.loads(params_str_1)
+    fund_weight_list = params['fund_weight_list']
+
+    start_date = params.get('start_date')
+    end_date = params.get('end_date')
+    start_date = datetime.datetime.strptime(start_date, '%Y-%m-%d').date()
+    end_date = datetime.datetime.strptime(end_date, '%Y-%m-%d').date()
+
+    b = BasicFundBacktestEngine(data_manager=data_manager, trader=t, fund_weight_list=fund_weight_list)
+    b.init()
+    # print(b._dm.dts.fund_index_map)
+    b.run(start_date=start_date, end_date=end_date, print_time=True)
+
 if __name__ == '__main__':
     # profile(file_name='/Users/cjiang/taa_perf1.txt', func=fund_backtest)
-    test()
\ No newline at end of file
+    test1()
