@@ -42,7 +42,7 @@ class ReportHelper:
     def init(self): 
         pass
 
-    def plot_init(self, dm, taa_helper):
+    def plot_init(self, dm, taa_helper=None):
         self.index_price = dm.get_index_price()
         self.fund_info = dm.get_fund_info()
         self.fund_nav = dm.dts.fund_nav
@@ -60,8 +60,8 @@ class ReportHelper:
             self.trade_df['year'] = [_.year for _ in self.trade_df.trade_date]
         self.pct_df = dm._index_pct_df
 
-    def setup(self, saa:AssetWeight):
-        self.saa_weight = saa.__dict__
+    def setup(self, saa:AssetWeight=None):
+        self.saa_weight = saa.__dict__ if saa else None
         self.asset_cash_history = {}
         self.asset_position_history = {}
         self.asset_market_price_history = {}
@@ -138,7 +138,7 @@ class ReportHelper:
 
     def _calc_stat(self, df):
         res = Calculator.get_stat_result_from_df(df=df.reset_index(), date_column='date', value_column='mv')
-        w = copy.deepcopy(self.saa_weight) # asset weight float
+        w = copy.deepcopy(self.saa_weight) if self.saa_weight else AssetWeight(hs300=1.0).__dict__ # asset weight float
         self._calc_stat_yearly(df)
         w['mdd'] = res.mdd #float
         w['annual_ret'] = res.annualized_ret #float
