@@ -2,7 +2,7 @@ from ...data.struct import AssetWeight, AssetPrice, AssetPosition, AssetValue
 from ...data.struct import AssetTrade, FundTrade, FundPosition, FundWeight
 from ...data.struct import AssetTradeParam, FundTradeParam
 from ...data.struct import AssetTradeCache, FundWeightItem
-from ...data.constant import TradeTrigger
+from ...data.constant import TradeTrigger, _DEFAULT_CASH_VALUE
 from . import Helper
 from .asset_helper import FAHelper
 import numpy as np
@@ -12,6 +12,7 @@ import datetime
 class AssetTrader(Helper):
 
     TRADE_DAY_INTERVAL = 10
+    DEFAULT_CASH_VALUE = _DEFAULT_CASH_VALUE
 
     def __init__(self, asset_param: AssetTradeParam=None):
         self.asset_param = asset_param or AssetTradeParam()
@@ -61,13 +62,16 @@ class AssetTrader(Helper):
         if not launch_trade:
             return cur_position, None
         else:
+            # #如果在极端参数下 设置MinCountAmtDiff比较大，导致小单被过滤掉，如果造成trade里只有 买单或者卖单， 放弃下单（会导致cash失控）
+            sell_trades_amt = sum([i.mark_price * i.volume for i in trades if i.is_buy is False])
+            buy_trades_amt = sum([i.amount for i in trades if i.is_buy is True])
+            if cur_position.cash != self.DEFAULT_CASH_VALUE and (sell_trades_amt == 0 or buy_trades_amt == 0):
+                return cur_position, None
             trades.sort(key=lambda x: x.is_buy)
             new_position = cur_position.copy()
             for trd in trades:
                 new_position.update(trd)
             #如果一个交易单过小，不达到交易下限，会被忽略，导致买单和卖单交易额相加不相等
-            buy_trades_amt = sum([i.amount for i in trades if i.is_buy is True])
-            sell_trades_amt = sum([i.mark_price * i.volume for i in trades if i.is_buy is False])
             buy_adjusted = sell_trades_amt / buy_trades_amt if (sell_trades_amt > 0 and buy_trades_amt > 0) else 1
             for trd in trades:
                 if trd.is_buy == True:
@@ -543,3 +547,167 @@ class FundTrader(AssetTrader):
         # sell_trades_amt = sum([i.mark_price * i.volume for i in fund_trades if i.is_buy is False]) 
         # print(f'  compare trades dt {dt} amt buy {buy_trades_amt} and sell {sell_trades_amt} diff {buy_trades_amt-sell_trades_amt }')
         return fund_trades
+
+class BasicFundTrader(Helper):
+
+    MIN_AMT_DIFF = 1.0
+    ENABLE_COMMISSION = True
+    PURCHASE_DISCOUNT = 0.15
+    REDEEM_DISCOUNT = 1.0
+
+    def __init__(self):
+        self.last_trade_date = None
+
+    # Used in basic strategy (manually prepared fund weights)
+    def calc_fund_trade(self, dt, fund_weight: FundWeight, cur_fund_position: FundPosition,
+                        cur_fund_nav: dict,
+                        fund_purchase_fees: dict,
+                        fund_redeem_fees: dict):
+        new_fund_position = cur_fund_position.copy()
+        fund_trades = []
+        # return trade list
+        fund_tot_mv, cur_fund_wgts = cur_fund_position.calc_mv_n_w(fund_navs=cur_fund_nav)
+        all_funds = {}
+        # prepare fund candidates and its index_id
+        for fund_id, fund_wgt_item in fund_weight.funds.items():
+            all_funds[fund_id] = fund_wgt_item.index_id
+        for fund_id, fund_pos_item in cur_fund_position.funds.items():
+            all_funds[fund_id] = fund_pos_item.index_id
+        # calc trade
+        for fund_id, index_id in all_funds.items():
+            target_fund_amt = fund_weight.get_wgt(fund_id) * fund_tot_mv
+            cur_fund_volume = cur_fund_position.get_volume(fund_id) or 0
+            p = cur_fund_nav[fund_id]
+            cur_fund_amt = cur_fund_volume * p
+
+            if abs(target_fund_amt - cur_fund_amt) > self.MIN_AMT_DIFF or (target_fund_amt == 0 and cur_fund_amt > 0):
+                is_buy = target_fund_amt > cur_fund_amt
+                if is_buy:
+                    _trade = FundTrade(
+                        fund_id=fund_id,
+                        index_id=index_id,
+                        mark_price=p,
+                        amount=abs(target_fund_amt - cur_fund_amt),
+                        is_buy=is_buy,
+                        submit_date=dt
+                    )
+                else:
+                    _trade = FundTrade(
+                        fund_id=fund_id,
+                        index_id=index_id,
+                        mark_price=p,
+                        volume=abs(target_fund_amt - cur_fund_amt)/p,
+                        is_buy=is_buy,
+                        submit_date=dt
+                    )
+                fund_trades.append(_trade)
+                #print(f'(fund){fund_id} (p){p} (amt0){cur_fund_amt} (amt1){target_fund_amt} (idx){index_id} (amt){abs(target_fund_amt - cur_fund_amt)} (direc) {target_fund_amt > cur_fund_amt} ')
+
+        fund_trades.sort(key=lambda x: x.is_buy)
+        for _trade in fund_trades:
+            new_fund_position.update(_trade)
+        return new_fund_position, fund_trades
+
+    def finalize_trade(self, dt, trades: list,
+                        t1_price: AssetPrice,
+                        bt_position: AssetPosition,
+                        cur_fund_position: FundPosition,
+                        cur_fund_nav: dict,
+                        cur_fund_unit_nav: dict,
+                        fund_purchase_fees: dict,
+                        fund_redeem_fees: dict,
+                        disproved_set: set):
+
+        if trades is None or len(trades) == 0:
+            return [], []
+
+        pendings = []
+        traded_list = []
+        # TODO: if some trades needs more time
+        # 先成交卖单， 再根据卖单成交金额 等额成交买单
+        for trd in trades:
+            trd.trade_price = cur_fund_nav[trd.fund_id]
+            trd.fund_unit_nav = cur_fund_unit_nav[trd.fund_id]
+            trd.volume = trd.volume if trd.volume else (trd.amount / trd.trade_price)
+            trd.amount = trd.amount if trd.amount else (trd.volume * trd.trade_price)
+            trd.fund_unit_volume = trd.amount / trd.fund_unit_nav
+            trd.trade_date = dt
+            if not trd.is_buy:
+                cur_vol = cur_fund_position.get_volume(trd.fund_id)
+                if not((cur_vol or 0) - trd.volume > -1e-8):
+                    #print(f'trade volume exceeds, adjusted to pos (fund_id){trd.fund_id} (vol){trd.volume} (is_buy){trd.is_buy} (pos){cur_vol}')
+                    assert cur_vol is not None, 'sell fund with no current position!'
+                    trd.volume = cur_vol
+                    trd.amount = trd.volume * trd.trade_price
+            
+            if self.ENABLE_COMMISSION:
+                if not trd.is_buy:
+                    redeem_fee = fund_redeem_fees[trd.fund_id] * self.REDEEM_DISCOUNT
+                    if np.isnan(redeem_fee):
+                        redeem_fee = 0
+                    trd.commission = trd.amount * redeem_fee
+                    trd.amount -= trd.commission
+            else:
+                trd.commission = 0
+            if not trd.is_buy:
+                trade_status = cur_fund_position.update(trd)
+                if trade_status:
+                    traded_list.append(trd)
+        _trade_list_buy = [i  for i in trades if i.is_buy is True]
+        _trade_list_sel = [i  for i in traded_list if i.is_buy is False]
+        plan_sel_amount = 0 if len(_trade_list_sel) < 1 else sum([i.amount for i in _trade_list_sel])
+        plan_buy_amount = 0 if len(_trade_list_buy) < 1 else sum([i.amount for i in _trade_list_buy])
+        if plan_sel_amount == 0 or plan_buy_amount == 0: 
+            buy_amount_adjusted_rate = 1
+        else:
+            buy_amount_adjusted_rate = plan_sel_amount / plan_buy_amount
+        
+        for trd in trades:
+            if not trd.is_buy:
+                continue
+            trd.amount *= buy_amount_adjusted_rate
+            if self.ENABLE_COMMISSION:
+                purchase_fee = fund_purchase_fees[trd.fund_id] * self.PURCHASE_DISCOUNT 
+                if np.isnan(purchase_fee):
+                    #print(f'fund_id {trd.fund_id} purchase fee data not avaiable')
+                    purchase_fee = 0
+                trd.volume = trd.amount / trd.trade_price / (1 + purchase_fee)
+                trd.commission = trd.volume * trd.trade_price * purchase_fee
+                trd.fund_unit_volume = trd.amount / trd.fund_unit_nav
+            else:
+                trd.commission = 0            
+                #print(f'trade is not permitted : {trd}')
+            trade_status = cur_fund_position.update(trd)
+            if trade_status:
+                traded_list.append(trd)
+            else:
+                pass
+                #print(f'trade failed alert : {trd}')
+        _trade_list_buy = [i  for i in traded_list if i.is_buy is True]
+        _trade_list_sel = [i  for i in traded_list if i.is_buy is False]
+        # plan_sel_amount = 0 if len(_trade_list_sel) < 1 else sum([i.amount for i in _trade_list_sel])
+        # plan_buy_amount = 0 if len(_trade_list_buy) < 1 else sum([i.amount for i in _trade_list_buy])
+        # print(f'trade date {dt} sell amount {plan_sel_amount} buy amount {plan_buy_amount} diff {plan_buy_amount-plan_sel_amount}')
+
+        # get cur asset weight from fund weight
+        cur_mv, cur_fund_weight = cur_fund_position.calc_mv_n_w(cur_fund_nav)
+        fund_index_dic = {}
+        for fund_id, fund_pos_item in cur_fund_position.funds.items():
+            fund_index_dic[fund_id] = fund_pos_item.index_id
+        asset_wgt = { _ : 0 for _ in set(fund_index_dic.values())}
+        for fund_id, wgt_i in cur_fund_weight.items():
+            index_id = fund_index_dic[fund_id]
+            asset_wgt[index_id] += wgt_i
+        # set index position:
+        for index_id in asset_wgt:
+            if index_id in t1_price.__dict__:
+                asset_p = t1_price.__dict__[index_id]
+            else:
+                asset_p = 1.0
+            amount = cur_mv * asset_wgt[index_id]
+            bt_position.__dict__[index_id] = amount / asset_p
+        
+        self.last_trade_date = dt
+        # fund cash -> asset cash
+        bt_position.cash = cur_fund_position.cash
+        return pendings, traded_list
