@@ -317,9 +317,9 @@ class Calculator:
             index_info = pandas.read_sql(query.statement, query.session.bind)
         with DerivedDatabaseConnector().managed_session() as mn_session:
             query = mn_session.query(
-                IndexValuation
+                IndexValuationLongTerm
             ).filter(
-                IndexValuation.datetime== dt,
+                IndexValuationLongTerm.datetime== dt,
             )
             index_val_df = pandas.read_sql(query.statement, query.session.bind)
         index_val = index_val_df.set_index('index_id').join(index_info.set_index('index_id')[['tag_method']]).reset_index()
@@ -335,9 +335,9 @@ class Calculator:
             index_info = pandas.read_sql(query.statement, query.session.bind)
         with DerivedDatabaseConnector().managed_session() as mn_session:
             query = mn_session.query(
-                IndexValuation
+                IndexValuationLongTerm
             ).filter(
-                IndexValuation.index_id.in_([index_id]),
+                IndexValuationLongTerm.index_id.in_([index_id]),
             )
             index_val_df = pandas.read_sql(query.statement, query.session.bind)
         index_val = index_val_df.set_index('index_id').join(index_info.set_index('index_id')[['tag_method']]).reset_index()
